@@ -27,7 +27,7 @@ log.addHandler(handler)
 
 __author__ = "Florian Matter"
 __email__ = "florianmatter@gmail.com"
-__version__ = "0.0.1"
+__version__ = "0.0.2"
 
 
 try:
@@ -107,6 +107,7 @@ def plot_map(  # noqa: MC0001
     tree_map_padding,
     tree_sort_mode,
     tree_depth,
+    tree_lw,
     internal_map_padding,
     seaborn_palette,
     color_dict,
@@ -114,8 +115,13 @@ def plot_map(  # noqa: MC0001
     leaf_marker_size,
     leaf_lw,
     map_marker_size,
+    map_marker_lw,
+    connection_lw,
     external_map_padding,
     font_size,
+    print_labels,
+    nonterminal_nodes,
+    color_tree,
     text_x_offset,
     text_y_offset,
     base_padding,
@@ -132,9 +138,12 @@ def plot_map(  # noqa: MC0001
     water_color = "lightgray"
     default_color = "orange"
     if feature_df is not None:
+        if "Clade" not in feature_df.columns or "Value" not in feature_df.columns:
+            raise ValueError("Feature dataframe has to have columns 'Clade' and 'Value'")
         lg_df = pd.merge(
-            lg_df, feature_df, left_on=id_col, right_on="Clade", how="left"
+            lg_df, feature_df, left_on=id_col, right_on="Clade", how="outer"
         )  # insert feature values into language table
+        lg_df[id_col] = lg_df.apply(lambda x: x["Clade"] if pd.isnull(x[id_col]) else x[id_col], axis=1)
         if color_dict is None:
             values = []
             for x in list(feature_df["Value"]):
@@ -163,6 +172,8 @@ def plot_map(  # noqa: MC0001
         lg_df, geometry=gpd.points_from_xy(lg_df.Longitude, lg_df.Latitude)
     )  # convert to a geodataframe
 
+    gdf.dropna(inplace=True, subset=["Latitude", "Longitude"])
+
     bounds = gdf.geometry.total_bounds  # outer boundaries of the language points
     rect = shapely.geometry.box(*bounds)  # as a shapely entity
     gdf["geometry"] = gdf["geometry"].rotate(
@@ -297,6 +308,7 @@ def plot_map(  # noqa: MC0001
         ax=ax,
         markersize=map_marker_size,
         facecolor=gdf["color"],
+        linewidth=map_marker_lw,
         edgecolor="black",
         zorder=99,
     )
@@ -348,6 +360,14 @@ def plot_map(  # noqa: MC0001
     to: {tree_baseline+tree_depth-child_depth}
     """
                 )
+                if color_tree:
+                    node_entries = lg_df[lg_df[id_col] == child.name]
+                    if len(node_entries) > 0:
+                        color = node_entries.iloc[0]["color"]
+                    else:
+                        color = "black"
+                else:
+                    color = "black"
                 ax.hlines(
                     sideline - get_clade_middle(child),
                     tree_baseline - clade_depth,
@@ -363,12 +383,18 @@ def plot_map(  # noqa: MC0001
                     node_alpha = 1
                     for point in gdf[gdf[id_col] == child.name].to_dict("records"):
                         map_node = (point["geometry"].x, point["geometry"].y)
+                        if print_labels:
+                            label_text = gdf[gdf[id_col] == child.name].iloc[0][
+                                label_column
+                            ]
+                        else:
+                            label_text = ""
                         ax.annotate(
                             xytext=(
                                 leaf_coords[0] + text_x_offset,
                                 leaf_coords[1] - text_y_offset,
                             ),
-                            text=gdf[gdf[id_col] == child.name].iloc[0][label_column],
+                            text=label_text,
                             # .upper(),
                             xy=map_node,
                             alpha=node_alpha,
@@ -379,6 +405,7 @@ def plot_map(  # noqa: MC0001
                                 "color": point["color"],
                                 "shrinkA": 0,
                                 "shrinkB": 3.5,
+                                "linewidth": connection_lw,
                                 "linestyle": "dotted",
                             },
                         )
@@ -394,6 +421,20 @@ def plot_map(  # noqa: MC0001
                     )
                     ax.add_patch(circle)
                 else:
+                    if nonterminal_nodes and child.name in color_dic:
+                        circle = plt.Circle(
+                            (
+                                tree_baseline - child_depth,
+                                sideline - get_clade_middle(child),
+                            ),
+                            leaf_marker_size,
+                            facecolor=color_dic[child.name],
+                            edgecolor="black",
+                            zorder=99,
+                            lw=leaf_lw,
+                        )
+                        ax.add_patch(circle)
+
                     draw_clade(child, color, lw)
 
     if feature_df is not None:
@@ -436,8 +477,10 @@ def plot_map(  # noqa: MC0001
 
     outer_rect.plot(ax=ax, edgecolor="black", facecolor="none", zorder=10, lw=1)
     mask.plot(ax=ax, color="white", alpha=1, edgecolor="black", lw=0.5)
+    tree_lw = tree_lw or plt.rcParams["lines.linewidth"]
 
-    draw_clade(tree.root, "black", plt.rcParams["lines.linewidth"])
+    tree_color = color_dic.get(tree.root.name, "black")
+    draw_clade(tree.root, tree_color, tree_lw)
 
     def get_attribution_position(position):
         if position == "bottomleft":
@@ -543,6 +586,7 @@ internal_map_padding = {internal_map_padding}
 text_x_offset = {text_x_offset}
 text_y_offset = {text_y_offset}
 tree_depth = {tree_depth}
+tree_lw = {tree_lw}
 base_padding = {base_padding}
 leaf_marker_size = {leaf_marker_size}"""
         )
